@@ -1,4 +1,4 @@
--- Copyright (c) 2018-2023, OARC, Inc.
+-- Copyright (c) 2018-2025 OARC, Inc.
 -- All rights reserved.
 --
 -- This file is part of dnsjit.
@@ -119,6 +119,16 @@ function Zpcap:zstd()
     self.obj.compression = "input_zpcap_type_zstd"
 end
 
+-- Use zlib/gzip to decompress the input file/data.
+function Zpcap:gzip()
+    self.obj.compression = "input_zpcap_type_gzip"
+end
+
+-- Use liblzma/xz to decompress the input file/data.
+function Zpcap:lzma()
+    self.obj.compression = "input_zpcap_type_lzma"
+end
+
 -- Return true if support for selected compression library is built in.
 function Zpcap:have_support()
     if C.input_zpcap_have_support(self.obj) == 1 then
